import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/analytics/modules/energy_management/blocs/power_clamp_info/power_clamp_info_bloc.dart';
import 'package:syncrow_web/pages/analytics/modules/energy_management/helpers/fetch_energy_management_data_helper.dart';
import 'package:syncrow_web/pages/space_tree/view/space_tree_view.dart';

class AnalyticsCommunitiesSidebar extends StatelessWidget {
  const AnalyticsCommunitiesSidebar({super.key});

  @override
  Widget build(BuildContext context) {
    return Builder(
      builder: (context) {
        return Expanded(
          child: SpaceTreeView(
            title: const Text('Communities'),
            shouldDisableDeselectingChildrenOfSelectedParent: true,
            onSelect: () {
              /// Necessary to wait for the state to update before fethcing the data.
              Future.delayed(
                const Duration(milliseconds: 100),
                () {
                  if (context.mounted) {
                    FetchEnergyManagementDataHelper.fetchEnergyManagementData(
                      context,
                    );
                    FetchEnergyManagementDataHelper.loadRealtimeDeviceChanges(
                      context,
                    );
                    context.read<PowerClampInfoBloc>().add(
                          const ClearPowerClampInfoEvent(),
                        );
                    final (selectedCommunities, selectedSpaces) =
                        FetchEnergyManagementDataHelper
                            .getSelectedCommunitiesAndSpaces(context);
                    if (selectedCommunities.isEmpty && selectedSpaces.isEmpty) {
                      context.read<PowerClampInfoBloc>().add(
                            const ClearPowerClampInfoEvent(),
                          );
                    } else {
                      FetchEnergyManagementDataHelper.loadPowerClampInfo(
                        context,
                      );
                    }
                  }
                },
              );
            },
            isSide: false,
          ),
        );
      },
    );
  }
}
